California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Go to Section:
| Statewide Candidates
| State Senate Candidates
| State Assembly Candidates
Choose an Election: 2022 PRIMARY 2021 SPECIAL ELECTION (ASSEMBLY 54) Prior Elections 2021 SPECIAL ELECTION (ASSEMBLY 79) 2021 SPECIAL ELECTION (STATE SENATE 30) 2020 GENERAL 2020 SPECIAL RUNOFF (STATE SENATE 28) 2020 PRIMARY 2020 SPECIAL ELECTION (STATE SENATE 28) 2019 SPECIAL RUNOFF (ASSEMBLY 01) 2019 SPECIAL ELECTION (ASSEMBLY 01) 2019 SPECIAL RUNOFF (STATE SENATE 01) 2019 SPECIAL RUNOFF (STATE SENATE 33) 2019 SPECIAL ELECTION (STATE SENATE 01) 2019 SPECIAL ELECTION (STATE SENATE 33) 2018 GENERAL 2018 SPECIAL RUNOFF (STATE SENATE 32) 2018 PRIMARY 2018 SPECIAL ELECTION (STATE SENATE 32) 2018 SPECIAL ELECTION (STATE SENATE 29) 2018 SPECIAL RUNOFF (ASSEMBLY 45) 2018 SPECIAL RUNOFF (ASSEMBLY 39) 2018 SPECIAL ELECTION (ASSEMBLY 45) 2018 SPECIAL ELECTION (ASSEMBLY 54) 2018 SPECIAL ELECTION (ASSEMBLY 39) 2017 SPECIAL RUNOFF (ASSEMBLY 51) 2017 SPECIAL ELECTION (ASSEMBLY 51) 2016 GENERAL 2016 PRIMARY 2016 SPECIAL ELECTION (ASSEMBLY 31) 2015 SPECIAL RUNOFF (STATE SENATE 07) 2015 SPECIAL ELECTION (STATE SENATE 37) 2015 SPECIAL ELECTION (STATE SENATE 21) 2015 SPECIAL ELECTION (STATE SENATE 07) 2014 SPECIAL ELECTION (STATE SENATE 35) 2014 GENERAL 2014 PRIMARY 2014 SPECIAL ELECTION (STATE SENATE 23) 2013 SPECIAL ELECTION (ASSEMBLY 54) 2013 SPECIAL RUNOFF (ASSEMBLY 45) 2013 SPECIAL RUNOFF (ASSEMBLY 52) 2013 SPECIAL ELECTION (STATE SENATE 26) 2013 SPECIAL ELECTION (ASSEMBLY 45) 2013 SPECIAL ELECTION (ASSEMBLY 52) 2013 SPECIAL RUNOFF (STATE SENATE 16) 2013 SPECIAL ELECTION (ASSEMBLY 80) 2013 SPECIAL ELECTION (STATE SENATE 16) 2013 SPECIAL RUNOFF (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 40) 2013 SPECIAL ELECTION (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 04) 2012 GENERAL 2012 SPECIAL ELECTION (STATE SENATE 04) 2012 PRIMARY 2011 SPECIAL RUNOFF (ASSEMBLY 04) 2011 SPECIAL ELECTION (ASSEMBLY 04) 2011 SPECIAL ELECTION (STATE SENATE 17) 2011 SPECIAL ELECTION (STATE SENATE 28) 2011 SPECIAL RUNOFF (STATE SENATE 01) 2010 GENERAL 2010 SPECIAL ELECTION (STATE SENATE 01) 2010 SPECIAL RUNOFF (STATE SENATE 15) 2010 SPECIAL ELECTION (STATE SENATE 15) 2010 PRIMARY 2010 SPECIAL RUNOFF (STATE SENATE 37) 2010 SPECIAL RUNOFF (ASSEMBLY 43) 2010 SPECIAL ELECTION (STATE SENATE 37) 2010 SPECIAL ELECTION (ASSEMBLY 43) 2010 SPECIAL RUNOFF (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 51) 2009 SPECIAL RUNOFF (STATE SENATE 26) 2009 SPECIAL ELECTION (STATE SENATE 26) 2008 GENERAL 2008 PRIMARY 2008 RECALL (STATE SENATE 12) 2008 SPECIAL RUNOFF (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 39) 2006 GENERAL 2006 PRIMARY 2006 SPECIAL RUNOFF (STATE SENATE 35) 2006 SPECIAL ELECTION (STATE SENATE 35) 2005 SPECIAL ELECTION (ASSEMBLY 53) 2004 GENERAL 2004 PRIMARY 2003 SPECIAL ELECTION (GOVERNOR) 2002 GENERAL 2002 PRIMARY 2001 SPECIAL ELECTION (ASSEMBLY 49) 2001 SPECIAL RUNOFF (ASSEMBLY 65) 2001 SPECIAL ELECTION (STATE SENATE 24) 2001 SPECIAL ELECTION (ASSEMBLY 65) 2000 GENERAL 2000 PRIMARY
Also check Late Contribution filings. These reports are independent of the comprehensive disclosure reports that are linked here until semi-annual filings are submitted.
SENATE DISTRICTS
STATE SENATE 01
AMBROZEWICZ, BOGDAN "BO" I. BAUGH, LES GAINES, EDWARD T GRIFFITH-FLATTER, JULIE
| STATE SENATE 03
CLIFT, GARY MIRANDA, FRANK WOLK, LOIS
STATE SENATE 05
BERRYHILL, WILLIAM R. GALGIANI, CATHLEEN ORNELLAS, LEROY
| STATE SENATE 07
DE SAULNIER, MARK MEUSER, MARK P.
STATE SENATE 09
HANCOCK, LONI MC ILROY, MARY CATHERINE RINGER, LISA D.
| STATE SENATE 11
DHILLON, HARMEET K. LENO, MARK
STATE SENATE 13
CHIANG, CHRISTOPHER K. HILL, JERRY A. LIEBER, SALLY WEBSTER, JOHN H.
| STATE SENATE 15
BEALL, JIM COTO, JOE
STATE SENATE 17
BEAMAN, LARRY G. MONNING, WILLIAM W.
| STATE SENATE 19
HODGE, JASON T. JACKSON, HANNAH-BETH STOKER, MIKE
STATE SENATE 21
KNIGHT, STEVE MOFFATT, STAR
| STATE SENATE 23
EMMERSON, BILL O'DONNELL, MELISSA R.
STATE SENATE 25
FULLER, AMEENAH R. GONZALES, GILBERT V. LIU, CAROL
| STATE SENATE 27
PAVLEY, FRAN ZINK, TODD
STATE SENATE 29
DIAMOND, GREGORY A. HUFF, ROBERT 'BOB'
| STATE SENATE 31
CLUTE, STEVE W. MILLER, JEFF ROTH, RICHARD D.
STATE SENATE 33
CHAUSER, LEE H. LARA, RICARDO
| STATE SENATE 35
BUTTERFIELD, PAUL SVOLOS, CHARLOTTE WRIGHT, RODERICK "ROD"
STATE SENATE 37
WALTERS, MIMI YOUNG, STEVEN RAY
| STATE SENATE 39
BLOCK, MARTY J. MARSH, PATRICK L. PLESCIA, GEORGE A.
ASSEMBLY DISTRICTS
ASSEMBLY 01
BOSETTI, RICK A. DAHLE, BRIAN EDWARDS, DAVID A. HOOPER, CHARLES L. MEACHER, ROBERT ANTHONY
| ASSEMBLY 02
CHESBRO, WESLEY ELIZONDO, PAMELA LYNCH, THOMAS DEAN PINI, FIRENZA X.
ASSEMBLY 03
LOGUE, DANIEL R. ROUSE, CHARLES E. WILLIAMS, ROBERT
| ASSEMBLY 04
MUNN, JOHN R. YAMADA, MARIKO M.
ASSEMBLY 05
BELDEN, MARK BIGELOW, FRANK BOYD, MARC FITZGERALD, TIMOTHY K. LANCASTER, KEVIN E. OLLER, THOMAS
| ASSEMBLY 06
BRONNER, REGINALD G. GAINES, BETH B. PUGNO, ANDREW
ASSEMBLY 07
DICKINSON, ROGER ZACHARIOU, JONATHAN
| ASSEMBLY 08
BONSER, JANICE M. FLYNN, JOHN T. ORTEGA, BARBARA TATEISHI, PETER TUFI, PHILLIP A.
ASSEMBLY 09
AMADOR, ANTONIO (TONY) NEMETH, EDWARD J. PAN, RICHARD SANTOS, TOM Y. SCHERMAN, SOPHIA GONZALES WEBER, C.T.
| ASSEMBLY 10
ALLEN, MICHAEL J. BOSWELL, JOSEPH JOHN EASTON-BROWN, ALEX GUNDERSON, DR., H. CHRISTIAN LEVINE, MARC MANCUS, PETER J. WONG, CONNIE O. Y.
ASSEMBLY 11
AUGUSTINE, LEN FRAZIER, JR., JAMES L GANTT, GENE HERNANDEZ, PATRICIA HUDSON, MICHAEL J. KINGETES, CHARLES F.
| ASSEMBLY 12
MATEO, CHRISTOPHER A. OLSEN, KRISTIN M.
ASSEMBLY 13
COOPER, DOLORES EGGMAN, SUSAN JAFRI, KHALID JEFFREY PADERES, XOCHITL STEBBINS, C. JENNET
| ASSEMBLY 14
BONILLA, SUSAN
ASSEMBLY 15
SKINNER, NANCY
| ASSEMBLY 16
BUCHANAN, JOAN PHILLIPS, ESTES A.
ASSEMBLY 17
AMMIANO, TOM CLARK, JASON P.
| ASSEMBLY 18
BONTA, ROB GUILLEN, ABEL WEBER, RHONDA A. YOUNG, JOEL B.
ASSEMBLY 19
BREYER, MICHAEL C. DEL CARLO, MATTHEW S. PAN, JAMES K. TING, PHIL
| ASSEMBLY 20
CHEEMA, SARABJIT KAUR GREEN, MARK ONG, JENNIFER QUIRK, BILL REYNOSO, LUIS
ASSEMBLY 21
GRAY, ADAM C. JONES, TOMMY C. MOBLEY JR., JACK M. RASMUSSEN, LESA SELLERS, ROBERT R.
| ASSEMBLY 22
GILHAM, MARK MULLIN, KEVIN C.
ASSEMBLY 23
DEFRANK, DAVID MOUANOUTOUA, VONG PATTERSON, JIM ROJAS, RICHARD R. WHALEN, ROBERT
| ASSEMBLY 24
ESPINOSA, GEBY E. GORDON, RICHARD S. ROSAS, JOSEPH ANTONELLI YANG, CHENGZHI "GEORGE"
ASSEMBLY 25
DIAMOND, ARLYNE M. MC HUGH, PETER A. WIECKOWSKI, ROBERT
| ASSEMBLY 26
CONWAY, CONNIE SOSA, JONATHON LOUIS
ASSEMBLY 27
CAMPOS, NORA ELIA LASSON, ROGER F.
| ASSEMBLY 28
FONG, PAUL WALSH, CHAD R.
ASSEMBLY 29
FULTZ, ROBERT B. STONE, MARK WALSH, TOM P.
| ASSEMBLY 30
ALEJO, LUIS BERNOSKY, ROBERT E.
ASSEMBLY 31
PEREA, HENRY T.
| ASSEMBLY 32
MC QUISTON, JON A. RIOS, PEDRO AYON SALAS JR., RUDY THOMAS, DAVID
ASSEMBLY 33
COFFEY, JOHN DONNELLY, TIM JAHN, WILLIAM E.
| ASSEMBLY 34
GOODMAN, VIRGINIA "MARI" GROVE, SHANNON
ASSEMBLY 35
ACHADJIAN, KHATCHIK MANATA, GERALD L.
| ASSEMBLY 36
FOX, STEVE LACKEY, THOMAS W. SMITH, RONALD D.
ASSEMBLY 37
WALTER, ROBIN T. WILLIAMS, DAS
| ASSEMBLY 38
HEADINGTON, EDWARD W. MC KEON, PATRICIA STRICKLAND, PAUL WILK, SCOTT T.
ASSEMBLY 39
ALARCON, RICHARD BENITEZ, RICARDO BOCANEGRA, RAUL CARRANZA, MARGIE CUEVAS, OMAR LINDBLAD, JOHN P. (JACK) SUSCAVAGE, KEVIN J.
| ASSEMBLY 40
MORRELL, MIKE WARNER, RUSS H.
ASSEMBLY 41
CACCIOTTI, MICHAEL ANTHONY COLTON, EDWARD A. HOLDEN, CHRIS LOWE, DONNA RUSNAK, VICTORIA
| ASSEMBLY 42
NESTANDE, BRIAN OROZCO, MARK
ASSEMBLY 43
GATTO, MIKE KRIKORIAN, GREGORY S.
| ASSEMBLY 44
GORELL, JEFF MAC ENERY, EILEEN MULLENS, JR., THOMAS A.
ASSEMBLY 45
BLUMENFIELD, BOB
| ASSEMBLY 46
HEALEY, LAURETTE JOHNSON, BRIAN C. LACHMAN, ANDREW LECAROS, ADRIANO NAZARIAN, ADRIN STERN, JAY L.
ASSEMBLY 47
BACA JR., JOE BROWN, CHERYL ENSLEY, JEANE M. WINKLER-BEACH, THELMA
| ASSEMBLY 48
HERNANDEZ, ROGER LARA-GARDNER, JOSEPH MEZA, MICHAEL G.
ASSEMBLY 49
CHAU, ED ING, MITCHELL LIN, MATTHEW
| ASSEMBLY 50
BLOOM, RICHARD BUTLER, BETSY OSBORN, TORIE TORGAN, BRADLY S.
ASSEMBLY 51
CHAVEZ, ARTURO FRIEDBERG, RICHARD F. GOMEZ, JIMMY GUTIERREZ, OSCAR A. LOPEZ, LUIS
| ASSEMBLY 52
AVILA, PAUL VINCENT COBLE, KENNETH E. MOORS, RAYMOND KENNETH TORRES, NORMA
ASSEMBLY 53
AGUILAR, JOSE T. ALDAPA, MICHAEL PEREZ, JOHN A. YOUNG, ROGER A.
| ASSEMBLY 54
MC COWEN, KEITH B. MITCHELL, HOLLY J. NICOLETTI, ED
ASSEMBLY 55
HAGMAN, CURT
| ASSEMBLY 56
PEREZ, V. MANUEL REYNAGA-EMETT, CORKY
ASSEMBLY 57
BERMUDEZ, RUDY CALDERON, IAN JAIMES, NOEL A.
| ASSEMBLY 58
AHMAD, SULTAN "SAM" CALDERON, THOMAS M. CRESPO, DANIEL GARCIA, CRISTINA KOTZE-RAMOS, PATRICIA A. MARQUEZ, LUIS H.
ASSEMBLY 59
AKILI, GREGORY HOLMES-MAGEE, GERTRUDE JONES-SAWYER SR., REGINALD BYRON NOURIDJANIAN, ARMENAK H. ROBINSON, RODNEY D.
| ASSEMBLY 60
KRAFT, GREGORY A. LINDER, ERIC PEREZ, JOSE L. SKIPWORTH, STANLEY T.
ASSEMBLY 61
BATEY, WILLIAM DE LEON, FRED R. KETCHAM, CARLOS T. LUDWIG, JOSEPH T. MEDINA, JOSE J.
| ASSEMBLY 62
BRADFORD, STEVEN EVANS, MERVIN
ASSEMBLY 63
GUERRERO, JACK M. MARTINEZ, DIANE J. RENDON, ANTHONY SARGENT, CATHRIN H.
| ASSEMBLY 64
HALL, ISADORE
ASSEMBLY 65
NORBY, CHRIS QUIRK-SILVA, SHARON
| ASSEMBLY 66
HUEY, CRAIG MINTZ, NATHAN M. MURATSUCHI, AL
ASSEMBLY 67
AKANA, WILLIAM T. DICKSON, KENNETH C. MAGEE, ROBERT E. MELENDEZ, MELISSA PAULE, PHIL
| ASSEMBLY 68
AVALOS, CHRISTINA WAGNER, DON
ASSEMBLY 69
BARRAGAN, FRANCISCO J. DALY, TOM MARTINEZ, MICHELE MORENO, JOSE L. PEREZ, JULIO
| ASSEMBLY 70
FLORES-GIBSON, MARTHA LOWENTHAL, BONNIE
ASSEMBLY 71
HURLEY, PATRICK J. JONES, BRIAN W. MC LAUGHLIN, JOHN T.
| ASSEMBLY 72
ALLEN, TRAVIS AYALA, ALBERT DOVINH, JOE EDGAR, TROY PHAM, LONG K.
ASSEMBLY 73
CORBETT, JAMES HARKEY, DIANE
| ASSEMBLY 74
DAIGLE, LESLIE J. MANSOOR, ALLAN R. RUSH, ROBERT L.
ASSEMBLY 75
HEROLD, MATTHEW A. WALDRON, MARIE
| ASSEMBLY 76
CHAVEZ, ROCKY DOUGLAS, FARRAH HODGES, SHERRY M.
ASSEMBLY 77
LASKARIS, GREG MAIENSCHEIN, BRIAN STEINER, DUSTIN M.
| ASSEMBLY 78
ATKINS, TONI G. DENNEY, RALPH WILLIAMS, ROBERT E.
ASSEMBLY 79
ENGLAND, MARY MENDOZA, MATT RAMIREZ, RUDY VOORAKKARA, SID C. WASHINGTON, PATRICIA A. WEBER, SHIRLEY
| ASSEMBLY 80
HUESO, BEN ROACH, DERRICK